clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"


local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"

*
* Least Traded Exercise - korus_ks
*

use "`in_dir'\USA_WORLD", replace

gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100

**import=1 corresponds to USA importing from Korea
gen import = 1 if importer == 842
replace import = 0 if exporter == 842

gen partner = 0 if importer == 0
replace partner = 0 if exporter == 0
replace partner = 410 if importer == 410
replace partner = 410 if exporter == 410

drop importer exporter pair

reshape wide value, i(import code year) j(partner)

gen valueROW = value0-max(value410,0)



save "`temp_dir'\temp", replace

*
* concord the NAFTA data
*


use "`in_dir'\SITC5_to_ISIC3",replace

rename sitc code

merge 1:m code using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge

replace isic = 2 if (int(isic2/100) == 2)
replace isic = 11 if (int(isic2/10) == 11)
replace isic = 12 if (int(isic2/10) == 12)
replace isic = 13 if (int(isic2/10) == 13)

save "`temp_dir'\temp", replace


insheet using "`in_dir'\raw\isic2other.csv", clear

keep isic2 korus_ks

merge 1:m isic2 using "`temp_dir'\temp"
drop if _merge == 2
drop _merge

save "`temp_dir'\temp", replace


*
* Reshape the data
*


gen pair = string(import,"%03.0f") + "-" + string(code,"%05.0f")

save "`temp_dir'\temp", replace

rename value410 value
drop value0

reshape wide value valueROW, i(pair) j(year)
drop valueROW2006 valueROW2007
rename valueROW2005 pre_val_ROW


gen pre_val = value2005


egen pre_val_avg = rowmean(value2005 value2006 value2007)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(import)
rename pre_val pre_total

merge 1:m import using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort import pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by import, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code sitc

keep import pre_val pre_val_ROW least sitc korus_ks

save "`temp_dir'\temp", replace


gen least_val_pre = least*pre_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val


*drop goods that wont be in our industry analysis
*this is the korus_ks analysis
drop if korus_ks == "NA"

collapse (sum) pre_val pre_val_ROW least_val_pre notleast_val_pre least notleast, by(import korus_ks)

save "`temp_dir'\temp", replace



gen importer = 842 if import == 1
replace importer = 0 if import == 0

gen exporter = 842 if import == 0
replace exporter = 0 if import == 1


gen usa = 1

gen fullpair = substr(korus_ks,1,4) + string(import)

save "`temp_dir'\temp", replace


*
*Merge in korus_ks Data
*

insheet using "`in_dir'\projections\korus_ks_input.txt", clear

replace korus_ks = substr(korus_ks,1,4)

drop kor_exports kor_imports

rename us_exports korus_ksgrowth0
rename us_imports korus_ksgrowth1

reshape long korus_ksgrowth, i(korus_ks) j(import)


gen fullpair = korus_ks + string(import)
drop korus_ks import

merge m:m fullpair using "`temp_dir'\temp"
drop _merge

save "`temp_dir'\temp", replace

*
* Predict growth in each industry
*

gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)
*gen perleast = least_val_pre/(least_val_pre+notleast_val_pre+pre_val_ROW)

**predicted growth in j = a + b * s_j
gen pred_val = pre_val*10.072 /100 + 40.720/100*least_val_pre if import == 1
replace pred_val = pre_val*31.026 /100 + 125.433/100*least_val_pre if import == 0


gen pre_tot = pre_val + pre_val_ROW

gen predgrowth = 100*((pred_val+pre_val+pre_val_ROW)/pre_tot-1)


label define imports 1 "Imports" 0 "Exports"
label values import imports

save "`out_dir'\korus_ks_USA_RESULTS", replace


eststo clear
bysort import: eststo: quietly estpost correlate predgrowth korus_ksgrowth [aweight = pre_tot]
esttab est* using "`out_dir'\tables\Table B5 KS-LTP corr.txt", label title(KiyotaStern-Perleast weighted correlation USA) nodepvar noobs b(2) nostar not replace

***save the tables
cd "`out_dir'"


use "`out_dir'\korus_ks_USA_RESULTS", replace
format korus_ksgrowth predgrowth %9.1f
format perleast %9.2f
keep if import == 0
order korus_ks korus_ksgrowth predgrowth perleast
keep korus_ks korus_ksgrowth predgrowth perleast
rename korus_ks sector
sort sector
outsheet using "`out_dir'\tables\Table B5 KORUS_KS USA Exports.txt", names replace


use "`out_dir'\korus_ks_USA_RESULTS", replace
format korus_ksgrowth predgrowth %9.1f
format perleast %9.2f
keep if import == 1
order korus_ks korus_ksgrowth predgrowth perleast
keep korus_ks korus_ksgrowth predgrowth perleast
rename korus_ks sector
sort sector
outsheet using "`out_dir'\tables\Table B5 KORUS_KS USA Imports.txt", names replace

