clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"


*
* Least Traded Exercise
*

use "`in_dir'\NAFTA", replace


gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

drop quantity quantityunitcode netweightkg

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value1989

*right now I have the save post val for non-Can numbers
gen post_val = value2009

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100


egen pre_val_avg = rowmean(value1989 value1990 value1991)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code sitc

keep importer exporter pre_val post_val least sitc

save "`temp_dir'\temp", replace



*
* concord the NAFTA data
*


use "`in_dir'\SITC5_to_ISIC3",replace

merge 1:m sitc using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge


gen least_val_pre = least*pre_val
gen least_val_post = least*post_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val
gen notleast_val_post = notleast*post_val


collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast, by(importer exporter isic2)

save "`temp_dir'\temp", replace


gen bds = int(isic2/100)
collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast if (bds != 3), by(importer exporter bds)
tostring bds, replace

save "`temp_dir'\temp2", replace



insheet using "`in_dir'\raw\isic2bds.csv", clear

merge 1:m isic2 using "`temp_dir'\temp"



collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast if (bds != ""), by(importer exporter bds)

append using "`temp_dir'\temp2"


save "`temp_dir'\temp", replace




*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

rename canada GDP124
rename unitedstates GDP842
rename mexico GDP484
drop world

reshape long GDP, i(year) j(exporter)


reshape wide GDP, i(exporter) j(year)

keep exporter GDP1989 GDP2009



*
* merge with NAFTA Data
*

merge 1:m exporter using "`temp_dir'\temp"
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009


gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)

gen growth = 100*((post_val/GDP_post)/(pre_val/GDP_pre)-1)


gen fullpair = bds + string(exporter) + string(importer)


save "`temp_dir'\temp", replace

*
*gen predicted results
*

*
*Merge in BDS Data
*

insheet using "`in_dir'\projections\bds_input.txt", clear

reshape long bdsgrowth, i(bds) j(pair)

gen fullpair = bds + string(pair)

merge m:m fullpair using "`temp_dir'\temp"
drop _merge



**predicted growth in j = alpha + beta * s_j
gen predgrowth = 16.240 + 67.813 * perleast if importer == 124 & exporter == 842
replace predgrowth =  8.592 + 35.879 * perleast if importer == 842 & exporter == 124
replace predgrowth =  15.048 + 62.834 * perleast if importer == 124 & exporter == 484
replace predgrowth =  11.469 + 47.891 * perleast if importer == 842 & exporter == 484
replace predgrowth =  30.305 + 126.538 * perleast if importer == 484 & exporter == 124
replace predgrowth =  29.939 + 125.011 * perleast if importer == 484 & exporter == 842



label values exporter country




save "`out_dir'\NAFTA_BDS_RESULTS", replace

*****
***correlations and regressions for tables 10 through 14
*****

cd "`out_dir'"


use "`out_dir'\NAFTA_BDS_RESULTS", replace

**if dont have estout install with following command
**ssc install estout, replace

label define ctry 124 "Can" 484 "Mex" 842 "USA"
label values importer ctry
label values exporter ctry


***correlation between BDS and Perleast

eststo clear
bysort exporter importer: eststo: quietly estpost correlate bdsgrowth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(BDS-Perleast weighted correlation) nodepvar noobs b(2) nostar not replace

***correlations with data and regressions

eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth bdsgrowth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(Weighted correlation with data) nodepvar noobs b(2) nostar not append

**alpha and beta bds industry estimates
eststo clear
bysort exporter importer: eststo: quietly reg growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 2 opt_coeff.txt", label title(Optimal coefficients with BDS industries) nodepvar noobs b(2) nostar not order(_cons perleast) varlabels(_cons alpha_LTP perleast beta_LTP) replace


**a and b regression fit for predictions
eststo clear
bysort exporter importer: eststo: quietly reg growth predgrowth [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(LTP predictions regression results) nodepvar noobs b(2) nostar not order(_cons predgrowth) varlabels(_cons a_LTP predgrowth b_LTP) append
eststo clear

eststo clear
bysort exporter importer: eststo: quietly reg growth bdsgrowth [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(BDS predictions regression results) nodepvar noobs b(2) nostar not order(_cons bdsgrowth) varlabels(_cons a_BDS bdsgrowth b_BDS) append
eststo clear


*** pooled correlations and regressions
eststo clear
eststo: quietly estpost correlate growth bdsgrowth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(Weighted correlation with data - POOLED) nodepvar noobs b(2) nostar not append

eststo clear
eststo: quietly reg growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 2 opt_coeff.txt", label title(Optimal coefficients with BDS industries - POOLED) nodepvar noobs b(2) nostar not order(_cons perleast) varlabels(_cons alpha_LTP perleast beta_LTP) append

eststo clear
eststo: quietly reg growth predgrowth [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(LTP predictions regression results - POOLED) nodepvar noobs b(2) nostar not order(_cons predgrowth) varlabels(_cons a_LTP predgrowth b_LTP) append
eststo clear

eststo clear
eststo: quietly reg growth bdsgrowth [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table 4-7 corr_reg.txt", label title(BDS predictions regression results - POOLED) nodepvar noobs b(2) nostar not order(_cons bdsgrowth) varlabels(_cons a_BDS bdsgrowth b_BDS) append
eststo clear



***
*Tables
***
use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 124
keep if importer == 842
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 4 BDS Can to US.txt", names replace

use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 842
keep if importer == 124
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 4 BDS US to Can.txt", names replace

use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 124
keep if importer == 484
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 5 BDS Can to Mex.txt", names replace

use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 484
keep if importer == 124
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 5 BDS Mex to Can.txt", names replace

use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 484
keep if importer == 842
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 6 BDS Mex to US.txt", names replace

use "`out_dir'\NAFTA_BDS_RESULTS", replace
format growth bdsgrowth predgrowth %9.1f
format perleast %9.2f
keep if exporter == 842
keep if importer == 484
order name growth bdsgrowth perleast predgrowth
keep name growth bdsgrowth perleast predgrowth
rename name sector
outsheet using "`out_dir'\tables\Table 6 BDS US to Mex.txt", names replace


