clear
clear matrix



*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"

*
* Least Traded Exercise - NAFTA Cox-Harris
*

use "`in_dir'\NAFTA", replace

gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100

gen import = 1 if importer == 484
replace import = 0 if exporter == 484

gen partner = 842 if importer == 842
replace partner = 842 if exporter == 842
replace partner = 124 if importer == 124
replace partner = 124 if exporter == 124

drop importer exporter pair
drop quantity quantityunitcode netweightkg

drop if import == .

reshape wide value, i(import code year) j(partner)

sleep 500
save "`temp_dir'\temp", replace

*
* concord the NAFTA data
*


use "`in_dir'\SITC5_to_ISIC3",replace

rename sitc code

merge 1:m code using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge

replace isic = 2 if (int(isic2/100) == 2)
replace isic = 11 if (int(isic2/10) == 11)
replace isic = 12 if (int(isic2/10) == 12)
replace isic = 13 if (int(isic2/10) == 13)

sleep 500
save "`temp_dir'\temp", replace


insheet using "`in_dir'\raw\isic2other.csv", clear

keep isic2 sobarzo

merge 1:m isic2 using "`temp_dir'\temp"
drop if _merge == 2
drop _merge

sleep 500
save "`temp_dir'\temp", replace


*
* Reshape the data
*


gen pair = string(import,"%03.0f") + "-" + string(code,"%05.0f")

sleep 500
save "`temp_dir'\temp", replace

rename value124 value_can
rename value842 value_usa

reshape wide value*, i(pair) j(year)


gen pre_val_can = value_can1989
gen pre_val_usa = value_usa1989
gen post_val_can = value_can2009
gen post_val_usa = value_usa2009


egen pre_val_can_avg = rowmean(value_can1989 value_can1990 value_can1991)
egen pre_val_usa_avg = rowmean(value_usa1989 value_usa1990 value_usa1991)

sleep 500
save "`temp_dir'\temp", replace


collapse (sum) pre_val_can pre_val_usa, by(import)
rename pre_val_can pre_can_total
rename pre_val_usa pre_usa_total

merge 1:m import using "`temp_dir'\temp"
drop _merge

sleep 500
save "`temp_dir'\temp", replace

*drop if pre_total==0
gen freq_can = pre_val_can/pre_can_total
gen freq_usa = pre_val_usa/pre_usa_total

*I might be mising a pre_val_avg in here

**first for the US
sort import pre_val_usa_avg

by import, sort: gen cum_freq_usa = sum(freq_usa)

gen least_usa=1 if cum_freq_usa<0.10
replace least_usa= (0.1-cum_freq_usa[_n-1])*pre_usa_total /pre_val_usa if cum_freq_usa >0.1 & cum_freq_usa[_n-1]<0.1
replace least_usa=0 if least_usa==.

**then for Canada
sort import pre_val_can_avg

by import, sort: gen cum_freq_can = sum(freq_can)

gen least_can=1 if cum_freq_can<0.10
replace least_can= (0.1-cum_freq_can[_n-1])*pre_can_total /pre_val_can if cum_freq_can >0.1 & cum_freq_can[_n-1]<0.1
replace least_can=0 if least_can==.


rename code sitc

drop pre_val_can_avg
drop pre_val_usa_avg

keep import pre_val_* post_val_* least* sitc sobarzo

sleep 500
save "`temp_dir'\temp", replace


gen least_val_pre_can = least_can*pre_val_can
gen least_val_pre_usa = least_usa*pre_val_usa

*gen notleast = abs(1-least)

*gen notleast_val_pre = notleast*pre_val


*drop goods that wont be in our industry analysis
*this is the sobarzo analysis
drop if sobarzo == "NA"

collapse (sum) pre_val* post_val* least*, by(import sobarzo)

sleep 500
save "`temp_dir'\temp", replace



gen importer = 484 if import == 1
replace importer = 0 if import == 0

gen exporter = 484 if import == 0
replace exporter = 0 if import == 1


gen fullpair = substr(sobarzo,1,4) + string(import)

sleep 500
save "`temp_dir'\temp", replace


*
*Merge in sobarzo projections
*

insheet using "`in_dir'\projections\sobarzo_input.txt", clear

replace sobarzo = substr(sobarzo,1,4)

rename exports sobarzo_growth0
rename imports sobarzo_growth1

reshape long sobarzo_growth, i(sobarzo) j(import)

gen fullpair = sobarzo + string(import)
drop sobarzo import

merge m:m fullpair using "`temp_dir'\temp"
drop _merge

sleep 500
save "`temp_dir'\temp", replace


*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

gen NA_GDP = canada+unitedstates

rename NA_GDP GDP1
rename mexico GDP0

drop unitedstates canada world

reshape long GDP, i(year) j(import)


reshape wide GDP, i(import) j(year)

keep import GDP1989 GDP2009



*
* merge with NAFTA Data
*

merge 1:m import using "`temp_dir'\temp"
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009

sleep 500
save "`temp_dir'\temp", replace

gen perleast = (least_val_pre_can + least_val_pre_usa)/( pre_val_usa + pre_val_can)

gen growth = 100*(((post_val_usa + post_val_can)/GDP_post)/((pre_val_usa + pre_val_can)/GDP_pre)-1)

*predicted trade value increase
gen pred_val = pre_val_can * 15.048 /100 + 62.834/100 *least_val_pre_can +  pre_val_usa * 11.469 /100 + 47.891/100 * least_val_pre_usa if import == 0
replace pred_val = pre_val_can * 30.305 /100 + 126.538/100 *least_val_pre_can +  pre_val_usa * 29.939 /100 + 125.011/100 * least_val_pre_usa if import == 1


gen pre_tot = pre_val_usa + pre_val_can
gen predgrowth =100*((pred_val+pre_tot)/(pre_tot)-1)


label define imports 1 "Imports" 0 "Exports"
label values import imports

sleep 500
save "`out_dir'\sobarzo_RESULTS", replace

*
*
* sobarzo Regressions and Results
*
*

use "`out_dir'\sobarzo_RESULTS", replace

*data correlations and regressions

eststo clear
bysort import: eststo: quietly estpost correlate sobarzo_growth predgrowth [aweight = pre_tot]
esttab est* using "`out_dir'\tables\Table A2 corr_reg.txt", label title(Sobarzo-Perleast weighted correlation) nodepvar noobs b(2) nostar not replace

eststo clear
bysort import: eststo: quietly estpost correlate growth sobarzo_growth predgrowth [aweight = pre_tot]
esttab est* using "`out_dir'\tables\Table A2 corr_reg.txt", label title(Weighted correlation with data) nodepvar noobs b(2) nostar not append


eststo clear
bysort import: eststo: quietly reg growth predgrowth [aweight = pre_tot]
esttab est* using "`out_dir'\tables\Table A2 corr_reg.txt", label title(LTP predictions regression results) nodepvar noobs b(2) nostar not order(_cons predgrowth) varlabels(_cons a_LTP predgrowth b_LTP)  append

eststo clear
bysort import: eststo: quietly reg growth sobarzo_growth [aweight = pre_tot]
esttab est* using "`out_dir'\tables\Table A2 corr_reg.txt", label title(Sobarzo predictions regression results) nodepvar noobs b(2) nostar not order(_cons sobarzo_growth) varlabels(_cons a_S sobarzo_growth b_S)  append


***save the tables
cd "`out_dir'"

use "`out_dir'\sobarzo_RESULTS", replace
format growth sobarzo_growth %9.1f
format predgrowth %9.1f
keep if import == 0
order sobarzo growth sobarzo_growth predgrowth
keep sobarzo growth sobarzo_growth predgrowth
rename sobarzo sector
sort sector
outsheet using "`out_dir'\tables\Table A2 Sobarzo Exports.txt", names replace


use "`out_dir'\sobarzo_RESULTS", replace
format growth sobarzo_growth %9.1f
format predgrowth %9.1f
keep if import == 1
order sobarzo growth sobarzo_growth predgrowth
keep sobarzo growth sobarzo_growth predgrowth
rename sobarzo sector
sort sector
outsheet using "`out_dir'\tables\Table A2 Sobarzo Imports.txt", names replace

