clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix_Dec2014\"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"


*
* Least Traded Exercise
*

use "`in_dir'\NAFTA", replace


gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

drop quantity quantityunitcode netweightkg

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value1989

*right now I have the save post val for non-Can numbers
gen post_val = value2009

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100


egen pre_val_avg = rowmean(value1989 value1990 value1991)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.20
replace least= (0.20-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.20 & cum_freq[_n-1]<0.20
replace least=0 if least==.


rename code sitc

keep importer exporter pre_val post_val least sitc

save "`temp_dir'\temp", replace



*
* concord the NAFTA data
*


use "`in_dir'\SITC5_to_ISIC3",replace

merge 1:m sitc using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge


gen least_val_pre = least*pre_val
gen least_val_post = least*post_val

gen notleast = abs(1-least)

gen notleast_val_pre = notleast*pre_val
gen notleast_val_post = notleast*post_val


collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast, by(importer exporter isic2)

save "`temp_dir'\temp", replace


gen bds = int(isic2/100)
collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast if (bds != 3), by(importer exporter bds)
tostring bds, replace

save "`temp_dir'\temp2", replace



insheet using "`in_dir'\raw\isic2bds.csv", clear

merge 1:m isic2 using "`temp_dir'\temp"



collapse (sum) pre_val post_val least_val_* notleast_val_* least notleast if (bds != ""), by(importer exporter bds)

append using "`temp_dir'\temp2"


save "`temp_dir'\temp", replace




*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

rename canada GDP124
rename unitedstates GDP842
rename mexico GDP484
drop world

reshape long GDP, i(year) j(exporter)


reshape wide GDP, i(exporter) j(year)

keep exporter GDP1989 GDP2009



*
* merge with NAFTA Data
*

merge 1:m exporter using "`temp_dir'\temp"
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009


gen perleast = least_val_pre/(least_val_pre+notleast_val_pre)

gen growth = 100*((post_val/GDP_post)/(pre_val/GDP_pre)-1)


gen fullpair = bds + string(exporter) + string(importer)


save "`temp_dir'\temp", replace


*labels
label define ctry 124 "Can" 484 "Mex" 842 "USA"
label values importer ctry
label values exporter ctry


***correlations with data and regressions

eststo clear
bysort exporter importer: eststo: quietly estpost correlate growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table A3 Cutoffs 20.txt", label title(Weighted correlation with data - 20% Cutoff) nodepvar noobs b(2) nostar not append

**alpha and beta bds industry estimates
eststo clear
bysort exporter importer: eststo: quietly reg growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table A3 Cutoffs 20.txt", label title(Optimal coefficients with BDS industries - 20% Cutoff) nodepvar noobs b(2) nostar not order(_cons perleast) varlabels(_cons alpha_LTP perleast beta_LTP) append



*** pooled correlations and regressions
eststo clear
eststo: quietly estpost correlate growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table A3 Cutoffs 20.txt", label title(Weighted correlation with data - 20% Cutoff - POOLED) nodepvar noobs b(2) nostar not append

eststo clear
eststo: quietly reg growth perleast [aweight = pre_val]
esttab est* using "`out_dir'\tables\Table A3 Cutoffs 20.txt", label title(Optimal coefficients with BDS industries - 20% Cutoff - POOLED) nodepvar noobs b(2) nostar not order(_cons perleast) varlabels(_cons alpha_LTP perleast beta_LTP) append
